@@ -60,7 +60,7 @@ def read_yaml(config_path, config_name=''):
     config_path:配置文件路径
     config_name:需要读取的配置内容,空则为全读
     """
-    if config_path:
+    if config_path and os.access(config_path, os.F_OK):
         with open(config_path, 'r', encoding="utf-8") as f:
             conf = yaml.safe_load(f.read())  # yaml.load(f.read())
         if not config_name:
@@ -70,7 +70,7 @@ def read_yaml(config_path, config_name=''):
         else:
             raise KeyError('未找到对应的配置信息')
     else:
-        raise ValueError('请输入正确的配置名称或配置文件路径')
+        raise ValueError('文件不存在，请输入正确的配置名称或配置文件路径')
 
 
 def save_yaml(name, content, mode='w+'):
